@@ -11,6 +11,7 @@ from pathlib import Path
 from typing import List, Tuple, Dict, Union, Optional, Any, Iterator, TypeVar
 
 from iotree.core.render.tables import tableFromRecords
+from iotree.core.render.funcs import basic_pbar
 
 from pisql.core.isql import iSQL
 from pisql.utils.render import console, errors
@@ -63,30 +64,36 @@ def executer(
     file = Path(file)
 
     if not override_default_dir:
-        dir = os.path.expanduser("~") / "pisql" / "results"
+        dir = Path(os.path.expanduser("~")) / "pisql" / "results"
         dir.mkdir(parents=True, exist_ok=True)
     else:
-        dir = Path(override_default_dir)
+        dir = Path(override_default_dir) if override_default_dir != "." else Path.cwd()
         dir.mkdir(parents=True, exist_ok=True)
 
-    df = isql.run_sql_file(file)
+    with basic_pbar() as pbar:
+        pbar.set_description(f"Executing {file.name}")
+        task = pbar.add_task("Waiting ...", total=None)
+        df = isql.run_sql_file(file)
 
-    csv_file = dir / "{file.stem}.csv"
-    parquet_file = dir / "{file.stem}.parquet"
+        pbar.update(task, advance=1)
+        pbar.set_description(f"Writing results to {dir}")
 
-    if out is None:
-        csv_out = df.write_csv(file=csv_file, row_oriented=True)
-        parquet_out = df.write_parquet(file=parquet_file, row_oriented=True)
-        records = orjson.loads(df.write_json(row_oriented=True))
-        console.print(tableFromRecords(records, theme="default"))
-    else:
-        outfile = dir / file.name
-        csv_out = df.write_csv(file=csv_file, row_oriented=True)
-        parquet_out = df.write_parquet(file=parquet_file, row_oriented=True)
-        if out.lower() in ["json", "excel"]:
-            errors.print(f"[bold red]Output format {out} not supported yet with the base version.[/]", style="bold red")
-            errors.print(f"[dim yellow]Please install `pandas` to get excel support[/]")
+        csv_file = dir / "{file.stem}.csv"
+        parquet_file = dir / "{file.stem}.parquet"
 
+        if out is None:
+            csv_out = df.write_csv(file=csv_file)
+            parquet_out = df.write_parquet(file=parquet_file)
+            records = orjson.loads(df.write_json(row_oriented=True))
+            console.print(tableFromRecords(records, theme="default"))
+        else:
+            outfile = dir / file.name
+            csv_out = df.write_csv(file=csv_file)
+            parquet_out = df.write_parquet(file=parquet_file)
+            if out.lower() in ["json", "excel"]:
+                errors.print(f"[bold red]Output format {out} not supported yet with the base version.[/]", style="bold red")
+                errors.print(f"[dim yellow]Please install `pandas` to get excel support[/]")
+                sys.exit(1)
         sys.exit(0)
 
 @dev.command(name="test", help="Run tests 🧪")
